summaryrefslogtreecommitdiff
path: root/src/libstrongswan/credentials/cert_validator.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/libstrongswan/credentials/cert_validator.h')
-rw-r--r--src/libstrongswan/credentials/cert_validator.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/libstrongswan/credentials/cert_validator.h b/src/libstrongswan/credentials/cert_validator.h
index 1e67c23ab..733d9d612 100644
--- a/src/libstrongswan/credentials/cert_validator.h
+++ b/src/libstrongswan/credentials/cert_validator.h
@@ -40,12 +40,13 @@ struct cert_validator_t {
* @param subject subject certificate to check
* @param issuer issuer of subject
* @param online wheter to do online revocation checking
* @param pathlen the current length of the path up to the root CA
* @param auth container for resulting authentication info
*/
bool (*validate)(cert_validator_t *this, certificate_t *subject,
- certificate_t *issuer, bool online, int pathlen,
- auth_cfg_t *auth);
+ certificate_t *issuer, bool online, u_int pathlen,
+ bool anchor, auth_cfg_t *auth);
};
#endif /** CERT_VALIDATOR_H_ @}*/
@@ -40,12 +40,13 @@ struct cert_validator_t {
* @param issuer issuer of subject
* @param online wheter to do online revocation checking
- * @param pathlen the current length of the path up to the root CA
+ * @param pathlen the current length of the path bottom-up
+ * @param anchor is issuer trusted root anchor
* @param auth container for resulting authentication info
*/